@@ -252,14 +252,8 @@ class DataVolume(NamespacedResource):
 
     @property
     def scratch_pvc(self):
-        pvc_metadata = self.pvc.instance.metadata
         scratch_pvc_prefix = (
-            f"prime-{pvc_metadata.uid}"
-            if pvc_metadata.annotations.get(
-                f"{self.ApiGroup.CDI_KUBEVIRT_IO}/storage.usePopulator"
-            )
-            == "true"
-            else self.name
+            self.pvc.prime_pvc.name if self.pvc.use_populator else self.name
         )
         return PersistentVolumeClaim(
             name=f"{scratch_pvc_prefix}-scratch",
